@@ -3,7 +3,7 @@ package Courriel::Helpers;
 use strict;
 use warnings;
 
-our $VERSION = '0.38';
+our $VERSION = '0.41';
 
 use Encode qw( decode );
 use Exporter qw( import );
@@ -27,10 +27,10 @@ sub fold_header {
     my $folded = q{};
 
     # Algorithm stolen from Email::Simple::Header
-    while ($line) {
+    while ( length $line ) {
         if ( $line =~ s/^(.{0,76})(\s|\z)// ) {
             $folded .= $1 . $CRLF;
-            $folded .= q{  } if $line;
+            $folded .= q{  } if length $line;
         }
         else {
 
@@ -190,7 +190,7 @@ sub _inflate_attribute {
 }
 
 sub unique_boundary {
-    return Email::MessageID->new()->user();
+    return Email::MessageID->new->user;
 }
 
 # Courriel::HeaderAttribute requires that $TSPECIALS be defined
